html_iliad = '''

<!doctype html>
<html lang="it">
<head>
   <meta charset="utf-8">

   <title>iliad - Benvenuto in iliad</title>
   
   <meta http-equiv="X-UA-Compatible" content="IE=edge">
   <meta name="viewport" content="width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0, user-scalable=no">

   <!-- Disable tap highlight on IE -->
   <meta name="msapplication-tap-highlight" content="no">

   <!-- Web Application Manifest -->
   <link rel="manifest" href="/manifest.json">

      <!-- Add to homescreen for Chrome on Android -->
   <meta name="mobile-web-app-capable" content="yes">
   <meta name="application-name" content="Iliad">
   <link rel="icon" type="image/png" sizes="192x192" href="/assets/favicon/android-icon-192x192.png">
   <link rel="icon" type="image/png" sizes="32x32" href="/assets/favicon/favicon-32x32.png">
   <link rel="icon" type="image/png" sizes="96x96" href="/assets/favicon/favicon-96x96.png">
   <link rel="icon" type="image/png" sizes="16x16" href="/assets/favicon/favicon-16x16.png">

   <!-- Add to homescreen for Safari on iOS -->
   <meta name="apple-mobile-web-app-capable" content="yes">
   <meta name="apple-mobile-web-app-status-bar-style" content="black">
   <meta name="apple-mobile-web-app-title" content="Iliad">
   <link rel="apple-touch-icon" sizes="57x57" href="/assets/favicon/apple-icon-57x57.png">
   <link rel="apple-touch-icon" sizes="60x60" href="/assets/favicon/apple-icon-60x60.png">
   <link rel="apple-touch-icon" sizes="72x72" href="/assets/favicon/apple-icon-72x72.png">
   <link rel="apple-touch-icon" sizes="76x76" href="/assets/favicon/apple-icon-76x76.png">
   <link rel="apple-touch-icon" sizes="114x114" href="/assets/favicon/apple-icon-114x114.png">
   <link rel="apple-touch-icon" sizes="120x120" href="/assets/favicon/apple-icon-120x120.png">
   <link rel="apple-touch-icon" sizes="144x144" href="/assets/favicon/apple-icon-144x144.png">
   <link rel="apple-touch-icon" sizes="152x152" href="/assets/favicon/apple-icon-152x152.png">
   <link rel="apple-touch-icon" sizes="180x180" href="/assets/favicon/apple-icon-180x180.png">

   <!-- Tile icon for Win8 (144x144 + tile color) -->
   <meta name="msapplication-TileImage" content="/assets/favicon/ms-icon-144x144.png">
   <meta name="msapplication-TileColor" content="#2F3BA2">

   <!-- Color the status bar on mobile devices -->
   <meta name="theme-color" content="#CC0000">

   <!-- OpenGraph (facebook) -->
         <meta property='og:image' content='https://www.iliad.it/assets/images/logo_iliad.png'/>
   
         <link rel="stylesheet" href="/assets/styles/custom-bootstrap.css?v=4b0da401526903dd5795756808390b64">
   <link rel="stylesheet" href="/assets/libs/remodal/remodal.css">
   <link rel="stylesheet" href="/assets/libs/remodal/remodal-default-theme.css">
   <link rel="stylesheet" href="/assets/libs/jquery-slidebars/slidebars.min.css?v=d61283d49cf7b1301d43aa04ff96b160">
   <link rel="stylesheet" href="/assets/styles/main.css?v=333b8c3c24a7f1cbd8cd01d068a6966e">

   <script src="/assets/libs/jquery-v3.2.1/jquery.min.js?v=c9f5aeeca3ad37bf2aa006139b935f0a"></script>
   <script src="/assets/libs/jquery-slidebars/slidebars.min.js?v=c1753c151e33bcb2899033de50cd2eeb"></script>
   <script src="/assets/scripts/common.min.js?v=d31a40d47a482ef0c816a9f2d22d74bd"></script>
   <script src="/assets/libs/remodal/remodal.min.js?v=27766f7f253c55e082376b092bcf2f1e"></script>

   <script src="/assets/libs/jquery-ui/jquery-ui.min.js?v=c91430307f7e60c25e1f39df9494c22f"></script>
   <link rel="stylesheet" href="/assets/libs/jquery-ui/jquery-ui.min.css?v=ec4ebe26afcae69ed461429b22179e16">
   <link rel="stylesheet" href="/assets/libs/jquery-ui/jquery-ui.theme.min.css?v=fedb1602fd53d77f216d11ecb15b782e">
   <link rel="stylesheet" href="/assets/libs/jquery-ui/jquery-ui.structure.min.css?v=880bfa2ab3cb8b3632512334b20cc99f">

   <script src="/assets/libs/jquery-slidebars/slidebars.min.js?v=c1753c151e33bcb2899033de50cd2eeb"></script>
   <link href="/assets/libs/jquery-slidebars/slidebars.min.css?v=d61283d49cf7b1301d43aa04ff96b160" rel="stylesheet">

   <link href="/account/styles/espace_abonne.css?v=dc5e16d46379367087ffa4084c339647" rel="stylesheet">
   <script src="/account/scripts/account.min.js?v=a62000ad008103643a973eca356d120c"></script>

   <script src="/assets/libs/svg-inject/svg-inject.min.js?v=ae60670a20f05e487c4748d9587b1f55"></script>
   <script>var fm_network = 1;</script> </head>

<body id="account-conso" class="main acc_conso" data-theme="main">

   <div class="remodal-bg">

      <nav id="navbar" class="navbar navbar-expand-md navbar-fm navbar-light remodal-bg">
   <div id="container" class="container-fluid container-smooth">
      <div class="navbar-header">
                     <div id="nav-icon" title="menu">
               <span></span>
               <span></span>
               <span></span>
            </div>
                  <a class="navbar-brand" href="//www.iliad.it">
            <img alt="iliad mobile" title="Benvenuto in iliad" src="/assets/images/logo.png">
         </a>
      </div>

               <div class="main-nav">
            <ul class="nav navbar-nav main-menu-items">
   <li>
      <a href="//www.iliad.it/offerte-iliad-mobile.html">
         <i class="i-sim"></i> Mobile
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/offerte-iliad-fibra.html">
         <i class="i-item-box"></i> Fibra
      </a>
   </li>
   <li>
      <a class="" href="//www.iliad.it/account/smartphone">
         <i class="i-item-mobile"></i> Smartphone
      </a>
   </li>
   <li>
      <a class="" href="https://puntivendita.iliad.it/map/">
         <i class="i-shop"></i> Punti vendita
      </a>
   </li>
   <li>
      <a href="https://assistenza.iliad.it">
         <i class="i-support"></i> Assistenza
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/perche-iliad.html">
         <i class="i-razzo"></i> Perché iliad?
      </a>
   </li>
</ul>
         </div>
      
      <div class="account">
         <ul class="buttons nav navbar-nav">
            <li class="nav-item"><a href="//www.iliad.it/account/"><i id="i-user" class="i-selfcare"></i><span class="hidden-phone"> Area Personale</span></a></li>
         </ul>
      </div>
   </div>
</nav>

      <div class="wrapper-page remodal-bg" >
         <div class="container container-smooth">
            <div class="main-nav nav-menu" role="navigation" off-canvas="main-nav left overlay">
               <ul class="nav navbar-nav main-menu-items">
   <li>
      <a href="//www.iliad.it/offerte-iliad-mobile.html">
         <i class="i-sim"></i> Mobile
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/offerte-iliad-fibra.html">
         <i class="i-item-box"></i> Fibra
      </a>
   </li>
   <li>
      <a class="" href="//www.iliad.it/account/smartphone">
         <i class="i-item-mobile"></i> Smartphone
      </a>
   </li>
   <li>
      <a class="" href="https://puntivendita.iliad.it/map/">
         <i class="i-shop"></i> Punti vendita
      </a>
   </li>
   <li>
      <a href="https://assistenza.iliad.it">
         <i class="i-support"></i> Assistenza
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/perche-iliad.html">
         <i class="i-razzo"></i> Perché iliad?
      </a>
   </li>
</ul>
            </div>
            <div class="main-menu-overlay"></div>

            
                     <nav class="nav-menu" role="navigation" off-canvas="main-menu left overlay">
         
<div class="list-users">
   <div class="current-user">
      <div class="current-user__icon i-user"></div>
      <div class="current-user__infos">
         <div class="bold identite">
            <i class="i-sim"></i>
            Massimo Cavalleri
         </div>

         <div class="smaller">
            ID utente: <span class="bold">64911165</span>
         </div>

         <div class="smaller">
            Linea: <span class="bold">3517216940</span>
         </div>

         <a href="/account/?logout=user">Esci</a>
      </div>
   </div>

   </div>

<ul class="menu">

   <li style="margin-bottom: 25px" class="title-item selected">
      <a href="/account/consumi-e-credito">
         <img src="/account/icons/consumption.svg" height="28" width="28" onload="SVGInject(this)" alt="Consumo">
         Consumi e credito
      </a>
   </li>
         <li class="title-item">
         <img src="/account/icons/selfcare.svg" height="28" width="28" onload="SVGInject(this)" alt="Selfcare">
         Profilo
      </li>
      <li class="block">
         <ul>
            <li >
               <a href="/account/dati-personali">Dati personali</a>
            </li>
                           <li >
                  <a href="/account/le-mie-opzioni">Le mie opzioni</a>
               </li>
                     </ul>
      </li>
      <li class="title-item">
      <img src="/account/icons/sim.svg" height="28" width="28" onload="SVGInject(this)" alt="Sim">
      La mia offerta mobile
   </li>
   <li class="block">
      <ul>
                     <li >
               <a href="/account/la-mia-offerta">La mia offerta</a>
            </li>
                  <li >
            <a href="/account/le-condizioni-della-mia-offerta">Le condizioni della mia offerta</a>
         </li>
                     <li >
               <a href="/account/i-miei-servizi">I miei servizi</a>
            </li>
            <li >
               <a href="/account/segreteria-telefonica">Segreteria telefonica</a>
                           </li>
                        </ul>
   </li>
         <li class="title-item">
         <img src="/account/icons/delivery.svg" height="28" width="28" onload="SVGInject(this)" alt="Delivery">
         I miei ordini
      </li>
      <li class="block">
         <ul>
                           <li >
                  <a href="/account/i-miei-ordini/sims">I miei ordini di SIM</a>
               </li>
                                       <li >
                  <a href="/account/i-miei-ordini">I miei ordini mobile</a>
               </li>
                     </ul>
      </li>
      </ul>

<ul class="nav navbar-nav main-menu-items">
   <li>
      <a href="//www.iliad.it/offerte-iliad-mobile.html">
         <i class="i-sim"></i> Mobile
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/offerte-iliad-fibra.html">
         <i class="i-item-box"></i> Fibra
      </a>
   </li>
   <li>
      <a class="" href="//www.iliad.it/account/smartphone">
         <i class="i-item-mobile"></i> Smartphone
      </a>
   </li>
   <li>
      <a class="" href="https://puntivendita.iliad.it/map/">
         <i class="i-shop"></i> Punti vendita
      </a>
   </li>
   <li>
      <a href="https://assistenza.iliad.it">
         <i class="i-support"></i> Assistenza
      </a>
   </li>
   <li>
      <a href="//www.iliad.it/perche-iliad.html">
         <i class="i-razzo"></i> Perché iliad?
      </a>
   </li>
</ul>
      </nav>
   
   <div id="container" canvas="container">
      <div class="page-container main">
         <div class="page-content">

                                          
                              
                                          
            
<div class="flash-container"></div>

                  <div class="page p-conso">

               <div class="marketing-consent-banner">
            <a href="/account/le-mie-opzioni/consenso-di-marketing">
               <img src="/account/images/banners/marketing_consent.png" alt="marketing-banner" style="width: 100%">
            </a>
         </div>
      
      
                              
      <div class="grid-l flex-container">
         <div class="grid-c w-4 double-rectangle decoration">
            <span class="bubble"></span>
            <div class="grid-l rectangle-content">
               <div class="grid-c w-4">
                  <h2>
                     <span class="bold">Offerta iliad Dati 300</span> - Credito : <b class="red">0.00€</b>
                     <div class="toggle-conso">
                        <a href="#" data-target="local" class="selected">In Italia</a>
                        |
                        <a href="#" data-target="roaming">Estero</a>
                     </div>
                  </h2>

                  <div class="grid-l banner-usa conso-infos conso-roaming">
                     <div class="grid-c w-4 w-desktop-6">
                        Hai in previsione di viaggiare negli USA? <a href="https://assistenza.iliad.it/mobile/supporto/22" class="underline" target="_blank">Preparati in tutta tranquillità!</a>
                     </div>
                  </div>

                  <div class="end_offerta">
                     La tua offerta iliad si rinnoverà alle 00:00 del 19/11/2022
                  </div>

                  <div class="conso-infos conso-local">
                     <div class="grid-l conso__grid">
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 Chiamate: <span class="red">0s</span><br>
                                 Consumi voce: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="voix">
                                 <div class="wrapper-align">
                                    <div class="i-call icon"></div>
                                    Chiamate
                                 </div>
                              </div>
                           </div>
                        </div>
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text"><span class="red">0 SMS</span><br>
                                 SMS extra: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="sms">
                                 <div class="wrapper-align">
                                    <div class="i-message icon"></div>
                                    SMS
                                 </div>
                              </div>
                           </div>
                        </div>
                     </div>
                     <div class="grid-l conso__grid">
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 <span class="red">67,18GB</span> / 300GB<br>
                                 Consumi Dati: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="data">
                                                                     <div id="conso-progress" class="progressbar"
                                         data-progress-value="22,39167771861"></div>
                                                                  <div class="wrapper-align">
                                                                        <div>
                                       <span class="big red">232</span>
                                       <span class="small red" style="text-transform:capitalize;">GB</span>
                                    </div>
                                    DATA
                                 </div>
                              </div>
                           </div>
                        </div>
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 <span class="red">0 MMS<br></span>
                                 Consumi MMS: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="mms">
                                 <div class="wrapper-align">
                                    <div class="i-mms icon"></div>
                                    MMS
                                 </div>
                              </div>
                           </div>
                        </div>
                     </div>
                  </div>

                  <div class="conso-infos conso-roaming">
                     <div class="grid-l conso__grid">
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 Chiamate: <span class="red">0s</span><br>
                                 Consumi voce: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="voix">
                                 <div class="wrapper-align">
                                    <div class="i-call icon"></div>
                                    Chiamate
                                 </div>
                              </div>
                           </div>
                        </div>
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text"><span class="red">0 SMS</span>
                                 <br>
                                 SMS extra: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="mms">
                                 <div class="wrapper-align">
                                    <div class="i-message icon"></div>
                                    SMS
                                 </div>
                              </div>
                           </div>
                        </div>
                     </div>
                     <div class="grid-l conso__grid">
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 <span class="red">0b</span> / 10GB<br>
                                 Consumi Dati: <span class="red">0.00€</span><br>
                                                               </div>
                              <div class="conso__icon" data-target="data">
                                                                     <div id="conso-progress" class="progressbar"
                                         data-progress-value="0"></div>
                                                                  <div class="wrapper-align">
                                                                        <div>
                                       <span class="big red">10</span>
                                       <span class="small red" style="text-transform:capitalize;">GB</span>
                                    </div>
                                    DATA
                                 </div>
                              </div>
                           </div>
                        </div>
                        <div class="grid-c w-4 w-tablet-4">
                           <div class="conso__content">
                              <div class="conso__text">
                                 <span class="red">0 MMS<br></span>
                                 Consumi MMS: <span class="red">0.00€</span>
                              </div>
                              <div class="conso__icon" data-target="mms">
                                 <div class="wrapper-align">
                                    <div class="i-mms icon"></div>
                                    MMS
                                 </div>
                              </div>
                           </div>
                        </div>
                     </div>
                  </div>

                  <div class="boutons">
                     <a href="/account/ricarica" class="bt-label bt-red bt-label-left bt-big bt-bold bt-square">
                        <span class="bt-icon i-money"></span>
                        Ricarica manualmente
                     </a>

                     <a href="/account/consumi-e-credito?historyId=0" class="bt-label bt-white bt-big bt-bold bt-square bt-label-left">
      <span class="bt-icon i-history"></span> <span>Storia</span></a>
                              <button id="toggle-details" type="button" class="bt-label bt-white bt-big bt-bold bt-square bt-label-right">
      <span>Dettaglio consumi</span> <span class="bt-icon i-eye"></span>   <span class="bt-label__state" style="display: none;" data-button-state="loading">               <span>Recupero in corso</span>         <span class="bt-icon bt-icon--loader"></span>
         </span>
   <span class="bt-label__state" style="display: none;" data-button-state="shown">               <span>Nascondi il dettaglio del consumo</span>         <span class="bt-icon i-eye-striked"></span>
         </span>
</button>

                  </div>

                  <div class="conso-details local">
                     <div class="conso-details__loader">
                        <p>Caricamento in corso, grazie per l&#039;attesa...</p>
                        <img src="/assets/images/loader/ajax-loader-horizontal.gif">
                     </div>
                  </div>

                  <div class="table-montant">
                     
                     <div class="label">Credito residuo</div>
                     <div class="red montant">0.00€</div>
                  </div>

                                 </div>
            </div>
         </div>
      </div>
   </div>

   <script>
     $(function () {
       Freemwork.conso.init();
     });
   </script>
         </div>
      </div>
   </div>
         </div>
      </div>

      <div id="footer" class="footer no-print">
   <div class="page-container">
      

      <div class="socials grid-l">
         <div class="grid-c">
            <a target="_blank" href="https://www.facebook.com/IliadItalia/" class="facebook">
               <img src="/assets/images/footer/facebook.svg" height="25" width="25" onload="SVGInject(this)" alt="Facebook">
            </a>
         </div>
         <div class="grid-c">
            <a target="_blank" href="https://www.instagram.com/iliaditalia" class="instagram">
               <img src="/assets/images/footer/instagram.svg" height="25" width="25" onload="SVGInject(this)" alt="Instagram">
            </a>
         </div>
         <div class="grid-c">
            <a target="_blank" href="https://www.tiktok.com/@iliaditalia" class="tiktok">
               <img src="/assets/images/footer/tiktok.svg" height="25" width="25" onload="SVGInject(this)" alt="Instagram">
            </a>
         </div>
         <div class="grid-c">
            <a target="_blank" href="https://twitter.com/IliadItalia" class="twitter">
               <img src="/assets/images/footer/twitter.svg" height="25" width="25" onload="SVGInject(this)" alt="Twitter">
            </a>
         </div>
         <div class="grid-c">
            <a target="_blank" href="https://www.linkedin.com/company/iliaditalia/" class="linkedin">
               <img src="/assets/images/footer/linkedin.svg" height="25" width="25" onload="SVGInject(this)" alt="Linkedin">
            </a>
         </div>
         <div class="grid-c">
            <a target="_blank" href="https://www.youtube.com/channel/UCIPsMRZ9208ceXgsCJovFDA" class="youtube">
               <img src="/assets/images/footer/youtube.svg" height="25" width="25" onload="SVGInject(this)" alt="Youtube">
            </a>
         </div>
      </div>
      <div class="grid-l">
         <div class="grid-c cell-top w-tablet-4 w-desktop-4 menu">
            <h5>I tuoi servizi</h5>
            <ul>
               <li><a href="//www.iliad.it/account/">Area Personale</a></li>
               <li><a href="https://assistenza.iliad.it">Assistenza</a></li>
               <li><a href="//www.iliad.it/account/ricarica">Ricarica</a></li>
               <li><a href="//www.iliad.it/copertura/index.html">Verifica copertura</a></li>
               <li><a href="https://puntivendita.iliad.it/map/">iliad Store</a></li>
               <li><a href="//www.iliad.it/contact.html">Contattaci</a></li>
            </ul>
         </div>
         <div class="grid-c cell-top w-tablet-4 w-desktop-4 menu">
            <h5>Termini e condizioni</h5>
            <ul>
               <li><a href="//www.iliad.it/condizioni-generali-di-contratto.html" target="_blank">Condizioni Generali di Contratto</a></li>
               <li>
                  <a href="//www.iliad.it/sintesi-contrattuale.html" target="_blank">
                     Sintesi contrattuale
                  </a>
               </li>
               <li><a href="/docs/informativa_privacy/informativa_privacy_2022-01-14.pdf" target="_blank" content="Informativa Privacy utenti iliad" title="Informativa Privacy.">Informativa Privacy utenti iliad</a></li>
               <li><a href="//www.iliad.it/roaming.html" target="_blank">Roaming</a></li>
               <li><a href="//www.iliad.it/trasparenza-tariffaria.html" target="_blank">Trasparenza Tariffaria</a></li>
               <li><a href="//www.iliad.it/brochure-prezzi.html" target="_blank">Brochure Prezzi</a></li>
               <li>
                  <a href="/docs/blocco_sms_bancari_a_pagamento.pdf" target="_blank">
                     Tariffe SMS bancari
                  </a>
               </li>
                              <li>
                  <a href="//www.iliad.it/carta-dei-servizi.html" target="_blank">Carta dei servizi</a>
               </li>
               <li>
                  <a href="//www.iliad.it/qualita-dei-servizi.html" target="_blank">Qualità dei servizi</a>
               </li>
               <li>
                  <a href="//www.iliad.it/agevolazioni-per-non-vedenti-e-non-udenti.html" target="_blank">Agevolazioni per non vedenti e non udenti</a>
               </li>
               <li><a href="//www.iliad.it/condizioni-di-utilizzo-del-sito.html" target="_blank">Condizioni di utilizzo e privacy del sito e delle app</a></li>
               <li><a href="//www.iliad.it/modulistica.html" target="_blank">Modulistica</a></li>
               <li><a href="/cookies.html" target="_blank">Impostazioni e Cookie policy</a></li>
            </ul>
         </div>
         <div class="grid-c cell-top w-tablet-4 w-desktop-4 menu">
            <h5>iliad</h5>
            <ul>
               <li><a href="https://corporate.iliad.it/chisiamo" target="_blank">Chi siamo</a></li>
               <li><a href="https://corporate.iliad.it/media/" target="_blank">Stampa</a></li>
               <li><a href="https://corporate.iliad.it/lavorareiniliad" target="_blank">Lavora con noi</a></li>
               <li><a href="https://corporate.iliad.it/solidali/" target="_blank">Iniziative solidali</a></li>
            </ul>
         </div>
      </div>
      <div class="conciliazione">
         Accedi alla piattaforma ConciliaWeb per presentare istanze di risoluzione delle controversie. Per maggiori informazioni
         <a href="https://www.agcom.it/procedura-di-conciliazione">https://www.agcom.it/procedura-di-conciliazione</a>
      </div>
      <div class="iliad-spa">
         <span class="bold">Iliad Italia S.p.A.</span><br>
         Sede legale: Viale Francesco Restelli 1/A - 20124, Milano - Partita IVA: 13970161009 - Numero REA: MI - 2126511 - Capitale sociale: 350.000.000 €
      </div>

                     <div class="mentions-link">
      
      
   
   
            

   
          

</div>
<div id="mentions">
      
      </div>
         </div>

   
</div>

   </div>

</body>
</html>
'''